
## Simple python package
This python package implements simple arithmetic functions, i.e., addition, subtraction and multiplication.


# Arithmetic Package Owais
Arithmetic Package Owais is a simple Python package that provides basic arithmetic functions such as addition, subtraction, and multiplication.

## Installation
The package name is "arithmeticPackageOwais" and its URL is https://pypi.org/project/arithmeticPackageOwais/.
To install the Arithmetic Package Owais, use pip:

```bash
pip install arithmeticTestPackage-Owais-md
```

## Usage

To use the functions, use the following command:
```bash 
from arithmeticPackageOwais import add, subtract, multiply
```
